@@ -1,35 +1,38 @@
 jq(function() {
 
+    var updateDropZoneHeight = function() {
+      jq('.dashboard-column').css('min-height', '0px');
+      var sizes = []
+      jq('.dashboard-column').each(function(index, value){
+        sizes.push(jq(value).height());
+      });
+      // set biggest value in array as min-height
+      jq('.dashboard-column').css('min-height', Math.max.apply(Math, sizes)+'px');
+    };
+
+    updateDropZoneHeight();
+
     var print_images = function(obj){
+        var actions = '<div class="portletActionsWrapper">';
+        // Fold functionality always
         if(jq('.documentEditable').length !== 0){
+            if (obj.parents('.portletwrapper:first').hasClass('folded')) {
+                actions += "<a class='dashboardButton buttonOpen' href='#'>&nbsp;</a>";
+            }
+            else{
+                actions+="<a class='dashboardButton buttonClose' href='#'>&nbsp;</a>";
+            }
             //Hash auslessen
             var hash = obj.parents('.portletwrapper:first')[0].id.substr('portletwrapper-'.length);
-            var actions = '<div class="portletActionsWrapper">';
-            //Fold Functionality
-            if (obj.parents('.portletwrapper:first').hasClass('folded')) {
-                 actions += "<div class='dashboardButton buttonOpen'><img src='"+portal_url+"/++resource++icon_open_box.gif' align='right' class='fold' alt='fold'/></div>";
-            }
-            else{
-                 actions+="<div class='dashboardButton buttonClose'><img src='"+portal_url+"/++resource++icon_close_box.gif' align='right' class='fold' alt='fold'/></div>";
-            }
-            actions += '<div class="dashboardButton buttonMove"><img src="'+portal_url+'/++resource++icon_move_box.gif" align="right" class="move" alt="move"/></div>';
+            actions += '<span class="dashboardButton buttonMove">&nbsp;</span>';
             if (obj.parents('.portletwrapper:first').hasClass('editable')) {
-                actions += '<div class="dashboardButton buttonEdit"><a class="edit" href="dashboardEditLinkView?hash='+hash+'"> <img src=" '+portal_url+'/++resource++icon_edit_box.gif" align="right" class="edit" alt="remove"> </a></div>';
-            }
-            actions += '<div class="dashboardButton buttonRemove"><img src="'+portal_url+'/++resource++icon_remove_box.gif" align="right" class="close" alt="remove"></img>';
-        }
-        else{
-            //Only Fold Functionality
-            if (jq(obj).parents('.portletwrapper:first').hasClass('folded')) {
-                 actions += "<div class='dashboardButton buttonOpen'><img src='"+portal_url+"/++resource++icon_open_box.gif' align='right' class='fold' alt='fold'/></div>";
-            }
-            else{
-                 actions += "<div class='dashboardButton buttonClose'><img src='"+portal_url+"/++resource++icon_close_box.gif' align='right' class='fold' alt='fold'/></div>";
+                actions += '<a class="dashboardButton buttonEdit" href="dashboardEditLinkView?hash='+hash+'">&nbsp;</a>';
             }
+            actions += '<a class="dashboardButton buttonRemove" href="#">&nbsp;</a>';
         }
         actions += '</div>';
         jq(actions).insertAfter(jq('.portletTopLeft',obj));
-    }
+    };
 
     var update_dashboard_order = function(event, ui) {
         // the update event handler is called twice (once with ui.sender
@@ -63,7 +66,7 @@ jq(function() {
                     //kss attribute portlethash must be fixed
                     if(jq('#portletwrapper-'+ oldHash).hasClass('kssattr-portlethash-'+oldHash)){
                         var classes = jq('#portletwrapper-' + oldHash)[0].getAttribute('class');
-                        if(classes!=null) {
+                        if(classes!==null) {
                             classes = classes.replace('kssattr-portlethash-' + oldHash, 'kssattr-portlethash-'+ newHash);
                             jq('#portletwrapper-'+ oldHash)[0].setAttribute('class', classes);
                         }
@@ -103,7 +106,7 @@ jq(function() {
         connectWith :   jq('.dashboard-column'),
         cursor :        'move',
         start :         function(){jq('body').addClass('dragPortlet');},
-        stop :          function(){jq('body').removeClass('dragPortlet');},
+        stop :          function(){jq('body').removeClass('dragPortlet');updateDropZoneHeight();},
         distance :      10,
         handle :        '.portletHeader',
         revert :        true,
@@ -114,19 +117,11 @@ jq(function() {
     jq('.column').disableSelection();
 
     /* TOGGLE PORTLET CONTENT */
-    jq('.portletHeader .fold').live('click',function() {
+    jq('.portletHeader a.buttonOpen, .portletHeader a.buttonClose').live('click',function(e) {
+      e.preventDefault();
         jq(this).parents('.portletwrapper:first').toggleClass('folded');
-
-        if (jq(this).parents('.portletwrapper:first').hasClass('folded')) {
-            //Change icon
-            this.setAttribute('src', portal_url+ '/++resource++icon_open_box.gif');
-            jq(this).parents('.dashboardButton:first').removeClass('buttonClose').addClass('buttonOpen');
-        }
-        else{
-            //Change icon
-            this.setAttribute('src', portal_url+ '/++resource++icon_close_box.gif');
-            jq(this).parents('.dashboardButton:first').removeClass('buttonOpen').addClass('buttonClose');
-        }
+        //Change icon
+        jq(this).toggleClass('buttonClose').toggleClass('buttonOpen');
 
         var wrapper = jq(this).parents('.portletwrapper:first');
         var hash = wrapper[0].id.substr('portletwrapper-'.length);
@@ -142,13 +137,14 @@ jq(function() {
         });
 
         //special workarround for fav portlet
-        if (jq(this).parents('.portletwrapper:first').find('.portletItem').length==0){
+        if (jq(this).parents('.portletwrapper:first').find('.portletItem').length===0){
             jq(this).parents('.portletwrapper:first').find('.portletItemEmpty').toggle().end();
             }
     });
 
     /* REMOVE PORTLET */
-    jq('.portletHeader .close').live('click',function() {
+    jq('.portletHeader a.buttonRemove').live('click',function(e) {
+        e.preventDefault();
         var wrapper = jq(this).parents('.portletwrapper:first');
         var hash = wrapper[0].id.substr('portletwrapper-'.length);
         // request
@@ -161,8 +157,7 @@ jq(function() {
         wrapper.hide().remove();
     });
 
-
-    /*REGISTER EVENT FOR PORTLETRELOAD*/
+    // This is needed when the calendar reloads to display the next month
     jq('.portletwrapper .portletHeader a').live('click', function(){
         jq(this).append(jq('<div class="crap"></div>'));
         var wrapper = jq(this).parents('.portletwrapper:first');
@@ -183,7 +178,7 @@ jq(function() {
     jq('.portletFavourites .close.favRemove').live('click',function(e){
         var uid = jq(this).attr('id');
         jq.post('./ftw_dashboard_dragndrop_remove_favorite',{ uid : uid },function(data){
-            if (data==''){
+            if (data===''){
                 alert('for some reason the favorite could not be delted, sorry');
             }
             if (data=='OK'){
@@ -192,8 +187,8 @@ jq(function() {
                     jq(v).remove();
                 });
 
-                if (jq('.portletFavourites .close.favRemove').length==0){
-                    jq('span.noFavs').closest('.portletItemEmpty').show()
+                if (jq('.portletFavourites .close.favRemove').length===0){
+                    jq('span.noFavs').closest('.portletItemEmpty').show();
                 }
             }
 
